@@ -1,7 +1,7 @@
 from sgtpyutils.logger import logger
 from .main import run, update_database as update
 from .LibcSearcher import LibcSearcher as Searcher
-from .LibcSearcher.commons import str_bin_sh as s_binsh, system as s_system, libc_start_main as s_libcstart, write as s_write, puts as s_puts, read as s_read
+from .LibcSearcher.commons import str_bin_sh as s_binsh, system as s_system, libc_start_main as s_libcstart, write as s_write, puts as s_puts, read as s_read, printf as s_printf
 from . import __version__
 logger.debug(
     f'{__version__.__title__} start, version:{__version__.__version__}')
